==> customized-facade-1.0.3-20190628.073718-9-sources.jar: com/bizvane/customized/facade/models/po/CusUrMbrStorageCardRecordPO.java <==
package com.bizvane.customized.facade.models.po;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.Date;
import java.math.BigDecimal;

@NoArgsConstructor
@AllArgsConstructor
@Builder
public class CusUrMbrStorageCardRecordPO implements Serializable {/**
	 * 只读. 储值卡日志自增id. mbr_storage_card_record_id
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "储值卡日志自增id", name = "mbrStorageCardRecordId", required = false, example = "")
	private Long mbrStorageCardRecordId;
	/**
	 * 只读. 线上企业id. sys_company_id
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线上企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 线上品牌id. brand_id
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线上品牌id", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. . member_code
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 转增人姓名. vip_name
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "转增人姓名", name = "vipName", required = false, example = "")
	private String vipName;
	/**
	 * 只读. 会员卡号 如:URV00000XXXX. vip_card_no
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员卡号 如:URV00000XXXX", name = "vipCardNo", required = false, example = "")
	private String vipCardNo;
	/**
	 * 只读. 转增人手机号. phone
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "转增人手机号", name = "phone", required = false, example = "")
	private String phone;
	/**
	 * 只读. 变更金额. balance
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "变更金额", name = "balance", required = false, example = "")
	private BigDecimal balance;
	/**
	 * 只读. 操作类型 1:新增 2：编辑 3：POS消费 4：商城消费 5：转赠 6:受赠 7：退回. op_type
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作类型 1:新增 2：编辑 3：POS消费 4：商城消费 5：转赠 6:受赠 7：退回", name = "opType", required = false, example = "")
	private Integer opType;
	/**
	 * 只读. 单据编号. bill_no
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "单据编号", name = "billNo", required = false, example = "")
	private String billNo;
	/**
	 * 只读. 目标人id. target_id
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "目标人id", name = "targetId", required = false, example = "")
	private Long targetId;
	/**
	 * 只读. 目标人. target_name
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "目标人", name = "targetName", required = false, example = "")
	private String targetName;
	/**
	 * 只读. . ops_id
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "opsId", required = false, example = "")
	private Long opsId;
	/**
	 * 只读. 操作人. ops_name
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作人", name = "opsName", required = false, example = "")
	private String opsName;
	/**
	 * 只读. 数据有效性 1=有效 0=无效. valid
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性 1=有效 0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. . remark
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名称. create_user_name
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名称", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人名称. modified_user_name
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人名称", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改日期. modified_date
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改日期", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 版本号. version
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 储值卡号. storage_card_no
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	@io.swagger.annotations.ApiModelProperty(value = "储值卡号", name = "storageCardNo", required = false, example = "")
	private String storageCardNo;
	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Long getMbrStorageCardRecordId() {
		return mbrStorageCardRecordId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setMbrStorageCardRecordId(Long mbrStorageCardRecordId) {
		this.mbrStorageCardRecordId = mbrStorageCardRecordId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getVipName() {
		return vipName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setVipName(String vipName) {
		this.vipName = vipName == null ? null : vipName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getVipCardNo() {
		return vipCardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setVipCardNo(String vipCardNo) {
		this.vipCardNo = vipCardNo == null ? null : vipCardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getPhone() {
		return phone;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setPhone(String phone) {
		this.phone = phone == null ? null : phone.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public BigDecimal getBalance() {
		return balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setBalance(BigDecimal balance) {
		this.balance = balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Integer getOpType() {
		return opType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setOpType(Integer opType) {
		this.opType = opType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getBillNo() {
		return billNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setBillNo(String billNo) {
		this.billNo = billNo == null ? null : billNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Long getTargetId() {
		return targetId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setTargetId(Long targetId) {
		this.targetId = targetId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getTargetName() {
		return targetName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setTargetName(String targetName) {
		this.targetName = targetName == null ? null : targetName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Long getOpsId() {
		return opsId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setOpsId(Long opsId) {
		this.opsId = opsId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getOpsName() {
		return opsName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setOpsName(String opsName) {
		this.opsName = opsName == null ? null : opsName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public String getStorageCardNo() {
		return storageCardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-25 18:21:42
	 */
	public void setStorageCardNo(String storageCardNo) {
		this.storageCardNo = storageCardNo == null ? null : storageCardNo.trim();
	}
}

==> customized-facade-1.0.3-20190628.100523-15-sources.jar: com/bizvane/customized/facade/models/po/CusUrMbrStorageCardRecordPO.java <==
package com.bizvane.customized.facade.models.po;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.Date;
import java.math.BigDecimal;

@NoArgsConstructor
@AllArgsConstructor
@Builder
public class CusUrMbrStorageCardRecordPO implements Serializable {/**
	 * 只读. 储值卡日志自增id. mbr_storage_card_record_id
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "储值卡日志自增id", name = "mbrStorageCardRecordId", required = false, example = "")
	private Long mbrStorageCardRecordId;
	/**
	 * 只读. 线上企业id. sys_company_id
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线上企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 线上品牌id. brand_id
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线上品牌id", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. . member_code
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 转增人姓名. vip_name
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "转增人姓名", name = "vipName", required = false, example = "")
	private String vipName;
	/**
	 * 只读. 会员卡号 如:URV00000XXXX. vip_card_no
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员卡号 如:URV00000XXXX", name = "vipCardNo", required = false, example = "")
	private String vipCardNo;
	/**
	 * 只读. 转增人手机号. phone
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "转增人手机号", name = "phone", required = false, example = "")
	private String phone;
	/**
	 * 只读. 变更金额. balance
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "变更金额", name = "balance", required = false, example = "")
	private BigDecimal balance;
	/**
	 * 只读. 操作类型 1:新增 2：编辑 3：转赠 4：受赠 5：消费 6:退回. op_type
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作类型 1:新增 2：编辑 3：转赠 4：受赠 5：消费 6:退回", name = "opType", required = false, example = "")
	private Integer opType;
	/**
	 * 只读. 单据编号. bill_no
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "单据编号", name = "billNo", required = false, example = "")
	private String billNo;
	/**
	 * 只读. 目标人id. target_id
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "目标人id", name = "targetId", required = false, example = "")
	private Long targetId;
	/**
	 * 只读. 目标人. target_name
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "目标人", name = "targetName", required = false, example = "")
	private String targetName;
	/**
	 * 只读. . ops_id
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "opsId", required = false, example = "")
	private Long opsId;
	/**
	 * 只读. 操作人. ops_name
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "操作人", name = "opsName", required = false, example = "")
	private String opsName;
	/**
	 * 只读. 数据有效性 1=有效 0=无效. valid
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性 1=有效 0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. . remark
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名称. create_user_name
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名称", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建日期. create_date
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人名称. modified_user_name
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人名称", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改日期. modified_date
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改日期", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 版本号. version
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 储值卡号. storage_card_no
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "储值卡号", name = "storageCardNo", required = false, example = "")
	private String storageCardNo;
	/**
	 * 只读. 订单编号. order_no
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "订单编号", name = "orderNo", required = false, example = "")
	private String orderNo;
	/**
	 * 只读. 验证id(幂等性). verify_id
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "验证id(幂等性)", name = "verifyId", required = false, example = "")
	private String verifyId;
	/**
	 * 只读. 储值卡余额. overage
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	@io.swagger.annotations.ApiModelProperty(value = "储值卡余额", name = "overage", required = false, example = "")
	private BigDecimal overage;
	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Long getMbrStorageCardRecordId() {
		return mbrStorageCardRecordId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setMbrStorageCardRecordId(Long mbrStorageCardRecordId) {
		this.mbrStorageCardRecordId = mbrStorageCardRecordId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getVipName() {
		return vipName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setVipName(String vipName) {
		this.vipName = vipName == null ? null : vipName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getVipCardNo() {
		return vipCardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setVipCardNo(String vipCardNo) {
		this.vipCardNo = vipCardNo == null ? null : vipCardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getPhone() {
		return phone;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setPhone(String phone) {
		this.phone = phone == null ? null : phone.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public BigDecimal getBalance() {
		return balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setBalance(BigDecimal balance) {
		this.balance = balance;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Integer getOpType() {
		return opType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setOpType(Integer opType) {
		this.opType = opType;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getBillNo() {
		return billNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setBillNo(String billNo) {
		this.billNo = billNo == null ? null : billNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Long getTargetId() {
		return targetId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setTargetId(Long targetId) {
		this.targetId = targetId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getTargetName() {
		return targetName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setTargetName(String targetName) {
		this.targetName = targetName == null ? null : targetName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Long getOpsId() {
		return opsId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setOpsId(Long opsId) {
		this.opsId = opsId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getOpsName() {
		return opsName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setOpsName(String opsName) {
		this.opsName = opsName == null ? null : opsName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getStorageCardNo() {
		return storageCardNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setStorageCardNo(String storageCardNo) {
		this.storageCardNo = storageCardNo == null ? null : storageCardNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getOrderNo() {
		return orderNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setOrderNo(String orderNo) {
		this.orderNo = orderNo == null ? null : orderNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public String getVerifyId() {
		return verifyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setVerifyId(String verifyId) {
		this.verifyId = verifyId == null ? null : verifyId.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public BigDecimal getOverage() {
		return overage;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-06-28 16:36:50
	 */
	public void setOverage(BigDecimal overage) {
		this.overage = overage;
	}
}
